/**************---< TECHNO ROAD.inc >---**************/
/*                                                   */
/*   File        :coron_usbcdc.c                     */
/*   Version     :v3.0.0                             */
/*   Date        :2014/05/09                         */
/*   Author      :                                   */
/*   Description :Coron USB CDC Library Source       */
/*                                                   */
/*    Copyright(C) TECHNO ROAD Inc.                  */
/*                 http://techno-road.com/           */
/*****************************************************/
#include "coron_conf.h"
#ifdef _CORON_USBCDC
/* Includes ------------------------------------------------------------------*/
#include "stm32f10x_lib.h"
#include "coron_lib.h"

/* Extern --------------------------------------------------------------------*/
extern LINE_CODING linecoding;

/* Global variables ----------------------------------------------------------*/
vu8 buffer_out[VIRTUAL_COM_PORT_DATA_SIZE];
vu8 buffer_in[VIRTUAL_COM_PORT_DATA_SIZE];
vu32 count_out;	//Mf[^
vu32 count_in;	//Mf[^

//==============================================================================
// Configures USB Clock input (48MHz)
//==============================================================================
void Set_USBClock(void)
{
  /* USBCLK = PLLCLK / 1.5 */
  RCC_USBCLKConfig(RCC_USBCLKSource_PLLCLK_1Div5);
//  RCC_USBCLKConfig(RCC_USBCLKSource_PLLCLK_Div1);
  /* Enable USB clock */
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_USB, ENABLE);
}

//==============================================================================
// Power-off system clocks and power while entering suspend mode
//==============================================================================
void Enter_LowPowerMode(void)
{
  /* Set the device state to suspend */
  bDeviceState = SUSPENDED;
}

//==============================================================================
// Restores system clocks and power while exiting suspend mode
//==============================================================================
void Leave_LowPowerMode(void)
{
  DEVICE_INFO *pInfo = &Device_Info;

  /* Set the device state to the correct state */
  if (pInfo->Current_Configuration != 0)
  {
    /* Device configured */
    bDeviceState = CONFIGURED;
  }
  else
  {
    bDeviceState = ATTACHED;
  }
}

//==============================================================================
// Configures the USB interrupts
//==============================================================================
void USB_Interrupts_Config(void)
{
  NVIC_InitTypeDef NVIC_InitStructure;

#ifdef  VECT_TAB_RAM
  /* Set the Vector Table base location at 0x20000000 */
  NVIC_SetVectorTable(NVIC_VectTab_RAM, 0x0);
#else  /* VECT_TAB_FLASH */
	#ifdef _DFU_MODE
		// Set the Vector Table base location at 0x08003000 for DFU
		NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x3000);
	#else
		// Set the Vector Table base location at 0x08000000
		NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x0);
	#endif
#endif

  NVIC_PriorityGroupConfig(NVIC_PriorityGroup_4);
  NVIC_StructInit(&NVIC_InitStructure);
  NVIC_InitStructure.NVIC_IRQChannel = USB_LP_CAN1_RX0_IRQn;
  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 1;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
  NVIC_Init(&NVIC_InitStructure);
}

//==============================================================================
// Software Connection/Disconnection of USB Cable
//==============================================================================
void USB_Cable_Config (FunctionalState NewState)
{
  if (NewState != DISABLE)
  {
    GPIO_ResetBits(USB_DISCONNECT, USB_DISCONNECT_PIN);
  }
  else
  {
    GPIO_SetBits(USB_DISCONNECT, USB_DISCONNECT_PIN);
  }
}

//==============================================================================
// Create the serial number string descriptor.
//==============================================================================
void Get_SerialNum(void)
{
  u32 Device_Serial0, Device_Serial1, Device_Serial2;

  Device_Serial0 = *(vu32*)(0x1FFFF7E8);
  Device_Serial1 = *(vu32*)(0x1FFFF7EC);
  Device_Serial2 = *(vu32*)(0x1FFFF7F0);

  if (Device_Serial0 != 0)
  {
    Virtual_Com_Port_StringSerial[2] = (u8)(Device_Serial0 & 0x000000FF);
    Virtual_Com_Port_StringSerial[4] = (u8)((Device_Serial0 & 0x0000FF00) >> 8);
    Virtual_Com_Port_StringSerial[6] = (u8)((Device_Serial0 & 0x00FF0000) >> 16);
    Virtual_Com_Port_StringSerial[8] = (u8)((Device_Serial0 & 0xFF000000) >> 24);

    Virtual_Com_Port_StringSerial[10] = (u8)(Device_Serial1 & 0x000000FF);
    Virtual_Com_Port_StringSerial[12] = (u8)((Device_Serial1 & 0x0000FF00) >> 8);
    Virtual_Com_Port_StringSerial[14] = (u8)((Device_Serial1 & 0x00FF0000) >> 16);
    Virtual_Com_Port_StringSerial[16] = (u8)((Device_Serial1 & 0xFF000000) >> 24);

    Virtual_Com_Port_StringSerial[18] = (u8)(Device_Serial2 & 0x000000FF);
    Virtual_Com_Port_StringSerial[20] = (u8)((Device_Serial2 & 0x0000FF00) >> 8);
    Virtual_Com_Port_StringSerial[22] = (u8)((Device_Serial2 & 0x00FF0000) >> 16);
    Virtual_Com_Port_StringSerial[24] = (u8)((Device_Serial2 & 0xFF000000) >> 24);
  }
}

#endif
